.ts-reason {
    max-width: 300px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

@keyframes ts-shake {
    0%, 100% { transform: translateX(0); }
    25% { transform: translateX(-5px); }
    50% { transform: translateX(5px); }
    75% { transform: translateX(-5px); }
}

.ts-shake {
    animation: ts-shake 0.5s;
    animation-iteration-count: infinite;
}

table.tax-table-striped>tbody>tr:nth-of-type(2n+1)>* {
    background-color: rgb(58 58 58 / 30%)
}

table.tax-table-hover>tbody>tr:nth-of-type(2n+1):hover>* {
    box-shadow: inset 0 0 0 9999px rgb(0 0 0 / 20%);
}

table.tax-table-hover>tbody>tr:nth-of-type(1n+1):hover>* {
    box-shadow: inset 0 0 0 9999px rgb(0 0 0 / 20%);
}

.tax-green {
    background-color: rgb(0 255 42 / 10%) !important;
}

.tax-warning {
    background-color: rgb(255 238 0 / 10%) !important;
}

.tax-red {
    background-color: rgb(255 0 0 / 10%) !important;
}

/* Fix X-Editable Cancel Button */

.editable-cancel {
    background-color: rgb(231 76 60 / 100%);
}

.editable-cancel:hover {
    background-color: rgb(231 76 60 / 70%);
}
