{% load i18n %}

<script type="application/javascript">
    let taxsystemsettings = {
        // Core
        corporation_id: {{ corporation_id }},
        character_id: {% if character_id %}{{ character_id }}{% else %}0{% endif %},
        csrf: "{{ csrf_token }}",
        // URLs
        corporationmanageDashboardUrl: '{% url "taxsystem:api:get_dashboard" corporation_id=corporation_id %}',
        corporationPaymentsUrl: '{% url "taxsystem:api:get_payments" corporation_id=corporation_id %}',
        corporationOwnPaymentsUrl: '{% url "taxsystem:api:get_own_payments" corporation_id=corporation_id %}',
        corporationMembersUrl: '{% url "taxsystem:api:get_members" corporation_id=corporation_id %}',
        corporationPaymentSystemUrl: '{% url "taxsystem:api:get_paymentsystem" corporation_id=corporation_id %}',
        // Update URLs
        corporationUpdateTaxUrl: '{% url "taxsystem:update_tax_amount" corporation_id=corporation_id %}',
        corporationUpdatePeriodUrl: '{% url "taxsystem:update_tax_period" corporation_id=corporation_id %}',
        // Translations
        translations: {
            days: '{% translate "days" %}',
            enterTaxAmount: "{% translate 'Enter Tax Amount' %}",
            enterTaxPeriod: "{% translate 'Enter Tax Period' %}",
            internalServerError: "{% translate 'Internal Server Error' %}",
            hasPaid: "{% translate 'Tax Paid' %}",
        }
    };
</script>
