{% extends 'taxsystem/base.html' %}
{% load i18n %}
{% load humanize %}
{% load taxsystem %}

{% block page_title %}
    {{ title }}
{% endblock %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block taxsystem_block %}
    <div class="card">
        <div class="card-header bg-primary rounded-top d-flex align-items-center">
            <h3 class="me-3">{% translate "Administration" %}</h3>
        </div>
        <div class="card-body">
            {% include 'taxsystem/partials/manage/dashboard.html' %}

            {% include 'taxsystem/partials/manage/paymentsystem.html' %}

            {% include 'taxsystem/partials/manage/members.html' %}
        </div>
    </div>
<!-- Tab Session -->
{% include 'taxsystem/modals/modal.html' with name="ViewPayments" %}
{% include 'taxsystem/modals/modal.html' with name="ViewDetails" %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_javascript %}
    <!-- load modals -->
    {% include 'taxsystem/bundles/modal-js.html' %}
    {% include 'taxsystem/modals/members-delete.html' %}
    {% include 'taxsystem/modals/payments-reject.html' %}
    {% include 'taxsystem/modals/payments-approve.html' %}
    {% include 'taxsystem/modals/payments-undo.html' %}
    {% include 'taxsystem/modals/payments-add.html' %}
    {% include 'taxsystem/modals/payments-delete.html' %}
    {% include 'taxsystem/modals/paymentsystem-switchuser.html' %}
    <script>
        setupModal('#modalViewPaymentsContainer', 'ajax_payments', '#modalViewPaymentsContent', '#modalViewPaymentsLoader');
        setupModal('#modalViewDetailsContainer', 'ajax_details', '#modalViewDetailsContent', '#modalViewDetailsLoader');
    </script>
    <!-- load the datatables-js-bs5.html bundle -->
    {% include 'bundles/datatables-js-bs5.html' %}
    {% include "bundles/filterdropdown-js.html" %}
    {% include 'bundles/moment-js.html' with locale=True %}
    <!-- load the settings bundle -->
    {% include "taxsystem/bundles/settings-css.html" %}
    {% include 'taxsystem/bundles/settings-js.html' %}
    <!-- load the administration bundle -->
    {% include 'taxsystem/bundles/administration-bundle.html' %}
{% endblock extra_javascript %}

{% block extra_script %}
{% endblock extra_script %}
