{% load i18n %}
<div class="table-responsive">
    <!-- Payments Content-->
    <table class="table table-dark table-striped w-100 tax-table-hover tax-table-striped" id="payments">
        <thead>
            <tr>
                <th scope="col"></th>
                <th scope="col">{% translate "Character Name" %}</th>
                <th scope="col">{% translate "ISK" %}</th>
                <th scope="col">{% translate "Date" %}</th>
                <th scope="col">{% translate "Status" %}</th>
                <th scope="col">{% translate "Actions" %}</th>
            </tr>
        </thead>

        <tbody>
            <!-- Payment Row -->
        </tbody>
    </table>
</div>
