{% load sri %}

{% sri_static 'taxsystem/js/payments.js' %}
{% sri_static 'taxsystem/js/modals/payments-reject.js' %}
{% sri_static 'taxsystem/js/modals/payments-approve.js' %}
{% sri_static 'taxsystem/js/modals/payments-undo.js' %}
{% sri_static 'taxsystem/js/modals/payments-delete.js' %}

{% sri_static 'taxsystem/css/cards.css' %}
