{% load i18n %}

<div class="card-header bg-primary rounded-top d-flex align-items-center mt-4">
    <h3 class="me-3">{% translate "Payment System" %}</h3>
</div>
<div class="card-body bg-secondary rounded-bottom">
    <!-- Payment System Content -->
    <table class="table table-dark table-striped w-100 tax-table-hover" id="payment-system">
        <thead>
            <tr>
                <th scope="col"></th>
                <th scope="col">{% translate "Character Name" %}</th>
                <th scope="col">{% translate "Status" %}</th>
                <th scope="col">{% translate "Deposit" %}</th>
                <th scope="col">{% translate "Tax Paid" %}</th>
                <th scope="col">{% translate "Last Debit" %}</th>
                <th scope="col">{% translate "Actions" %}</th>
            </tr>
        </thead>

        <tbody>
            <!-- Payment Users -->
        </tbody>
    </table>
</div>
